==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/WikiPage/BracketNameParser.pm <==
#
# WiKicker
#
#  BracketNameParser.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: BracketNameParser.pm,v 1.2 2003/10/26 23:07:34 naney Exp $
#
#

package WiKicker::WikiPage::BracketNameParser;

use strict;
use Carp;
use WiKicker::WikiPage::BracketNameNode;

sub new {
  my ($class, %param) = @_;

  croak "no wri_factory" unless exists $param{wri_factory};

  my $self = bless { wri_factory => $param{wri_factory}}, $class;

  return $self;
}

sub parse {
  my ($self, $string) = @_;

  my $tmp = substr($string, 2, length($string) - 4);
  my ($reference, $content);
  if ($tmp =~ /^((?:[^]]|(?:\\.)|(?:\][^[]))*?)\]\[(.*)$/) {
    $reference = $1;
    $content = $2;
  }
  else {
    $reference = $tmp;
    $content = undef;
  }

  return WiKicker::WikiPage::BracketNameNode
    ->new($string, $reference, $content, $self->{wri_factory});
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/WikiPage/BracketNameParser.pm <==
#
# WiKicker
#
#  BracketNameParser.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: BracketNameParser.pm,v 1.3 2004/08/03 12:55:52 naney Exp $
#
#

package WiKicker::WikiPage::BracketNameParser;

use strict;
use Carp;
use WiKicker::WikiPage::BracketNameNode;

sub new {
  my ($class, %param) = @_;

  croak 'no wri_factory' unless exists $param{wri_factory};

  my $self = bless { wri_factory => $param{wri_factory}}, $class;

  return $self;
}

sub parse {
  my ($self, $string) = @_;

  my $tmp = substr($string, 2, length($string) - 4);
  my ($reference, $content);
  if ($tmp =~ /^((?:[^]]|(?:\\.)|(?:\][^[]))*?)\]\[(.*)$/) {
    $reference = $1;
    $content = $2;
  }
  else {
    $reference = $tmp;
    $content = undef;
  }

  return WiKicker::WikiPage::BracketNameNode
    ->new($string, $reference, $content, $self->{wri_factory});
}

1;
